Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2005-07-22 20:40:26 +0400
committerDaniel Dunbar <daniel@zuster.org>2005-07-22 20:40:26 +0400
commitb6b352e0b72237f7892d72c893cad1bfb0f1337d (patch)
tree043fca777a812f27d29a690fb5dc99ee06d69099 /intern/guardedalloc/MEM_guardedalloc.h
parent9e502dae6f05b15575e6882c803f59d989cfdb0e (diff)
- got fed up with not being able to put a breakpoint on MEM_
errors, switched MEM_set_error_stream to MEM_set_error_callback that calls a function to print result instead of just giving a FILE * Note: requires intern recompile
Diffstat (limited to 'intern/guardedalloc/MEM_guardedalloc.h')
-rw-r--r--intern/guardedalloc/MEM_guardedalloc.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/intern/guardedalloc/MEM_guardedalloc.h b/intern/guardedalloc/MEM_guardedalloc.h
index 6280b52059c..e909e7eee45 100644
--- a/intern/guardedalloc/MEM_guardedalloc.h
+++ b/intern/guardedalloc/MEM_guardedalloc.h
@@ -98,8 +98,8 @@ extern "C" {
* blocks. */
void MEM_printmemlist(void);
- /** Set the stream for error output. */
- void MEM_set_error_stream(FILE*);
+ /** Set the callback function for error output. */
+ void MEM_set_error_callback(void (*func)(char *));
/**
* Are the start/end block markers still correct ?